Trait EnumeratedCharProperty

trait EnumeratedCharProperty: Sized + CharProperty

A Character Property with enumerated values.

This is similar to types Enumeration and Catalog, as defined in UAX#44.

Usage Note: If the property is of type Catalog, it's recommended to (in some way) mark the type as non-exhaustive, so that adding new variants to the enum type won't result in API breakage.

Required Methods

fn all_values() -> &'static [Self]

Exhaustive list of all property values.

fn abbr_name(self: &Self) -> &'static str

The abbreviated name of the property value.

fn long_name(self: &Self) -> &'static str

The long name of the property value.

fn human_name(self: &Self) -> &'static str

The human-readable name of the property value.